@@ -1,6 +1,6 @@
 use super::{
-    BodyItem, Comment, CustomProperty, Import, MediaRule, Property, Rule,
-    Value,
+    BodyItem, Comment, CustomProperty, Import, Item, MediaRule, Property,
+    Rule, Value,
 };
 use crate::output::CssBuf;
 use std::io::{self, Write};
@@ -128,3 +128,18 @@ impl From<BodyItem> for AtRuleBodyItem {
         }
     }
 }
+
+impl TryFrom<Item> for AtRuleBodyItem {
+    type Error = &'static str;
+
+    fn try_from(value: Item) -> Result<Self, Self::Error> {
+        match value {
+            Item::Comment(x) => Ok(x.into()),
+            Item::Import(x) => Ok(x.into()),
+            Item::Rule(x) => Ok(x.into()),
+            Item::MediaRule(x) => Ok(x.into()),
+            Item::AtRule(x) => Ok(x.into()),
+            Item::Separator => Err("separator not supported here"),
+        }
+    }
+}
