@@ -77,6 +77,15 @@ impl CallArgs {
         }
     }
 
+    pub(crate) fn get_single(&self) -> Result<&Value, ArgsError> {
+        self.check_no_named()?;
+        match self.positional.len() {
+            1 => Ok(self.positional.first().unwrap()),
+            0 => Ok(&Value::Null),
+            n => Err(ArgsError::TooMany(1, n)),
+        }
+    }
+
     pub(crate) fn check_no_named(&self) -> Result<(), ArgsError> {
         if let Some(extra) = self.named.keys().next() {
             Err(ArgsError::Unexpected(extra.clone()))
