@@ -8,40 +8,41 @@
 //! leafs of simple selectors in some future release.
 use super::{is_not, CssString, Value};
 use crate::input::SourcePos;
-use crate::parser::css::{selector, selector_part, selectors};
+use crate::parser::css::{selector, selector_parts, selectors};
 use crate::parser::{input_span, ParseError};
 use crate::value::ListSeparator;
 use std::fmt;
 use std::io::Write;
 
-/// A full set of selectors
+mod logical;
+pub(crate) use logical::SelectorSet as LogicalSelectorSet;
+
+/// A full set of selectors.
 #[derive(Clone, Debug, PartialEq, Eq, PartialOrd)]
 pub struct Selectors {
-    /// The actual selectors.
     s: Vec<Selector>,
-    backref: Selector,
 }
 
 impl Selectors {
     /// Create a root (empty) selector.
     pub fn root() -> Self {
-        Selectors::new(vec![Selector::root()])
+        Selectors {
+            s: vec![Selector::root()],
+        }
     }
     /// Return true if this is a root (empty) selector.
     pub fn is_root(&self) -> bool {
-        self.s == [Selector::root()] && self.backref == Selector::root()
+        self.s == [Selector::root()]
     }
-    /// Create a new Selectors from a vec of selectors.
+    /// Create a new `Selectors` from a vec of selectors.
     pub fn new(s: Vec<Selector>) -> Self {
-        Selectors {
-            s: if s.is_empty() {
-                vec![Selector::root()]
-            } else {
-                s
-            },
-            backref: Selector::root(),
+        if s.is_empty() {
+            Selectors::root()
+        } else {
+            Selectors { s }
         }
     }
+
     /// Validate that this selector is ok to use in css.
     ///
     /// `Selectors` can contain backref (`&`), but those must be
@@ -55,7 +56,7 @@ impl Selectors {
         }
     }
 
-    /// Remove the first of these selectors (or the root selector if empty).
+    /// Get the first of these selectors (or the root selector if empty).
     pub(crate) fn one(&self) -> Selector {
         self.s.first().cloned().unwrap_or_else(Selector::root)
     }
@@ -87,17 +88,8 @@ impl Selectors {
     }
 
     /// Create the full selector for when self is used inside a parent selector.
-    pub(crate) fn inside(&self, parent: &Self) -> Self {
-        let mut result = Vec::new();
-        for p in &parent.s {
-            for s in &self.s {
-                result.push(p.join(s, &parent.backref));
-            }
-        }
-        Selectors {
-            s: result,
-            backref: parent.backref.clone(),
-        }
+    pub(crate) fn inside(&self, parent: &SelectorCtx) -> Self {
+        SelectorCtx::from(self.clone()).inside(parent).real()
     }
 
     /// True if any of the selectors contains a backref (`&`).
@@ -105,13 +97,36 @@ impl Selectors {
         self.s.iter().any(Selector::has_backref)
     }
 
+    /// Get a vec of the non-placeholder selectors in self.
+    pub fn no_placeholder(&self) -> Option<Self> {
+        let s = self
+            .s
+            .iter()
+            .filter_map(Selector::no_placeholder)
+            .collect::<Vec<_>>();
+        if s.is_empty() {
+            None
+        } else {
+            Some(Selectors { s })
+        }
+    }
+
+    fn no_leading_combinator(mut self) -> Option<Self> {
+        self.s.retain(|s| !s.has_leading_combinator());
+        if self.s.is_empty() {
+            None
+        } else {
+            Some(self)
+        }
+    }
+
     /// Get these selectors with a specific backref selector.
     ///
     /// Used to create `@at-root` contexts, to have `&` work in them.
-    pub(crate) fn with_backref(self, context: Selector) -> Self {
-        self.inside(&Selectors {
-            s: vec![Selector::root()],
-            backref: context,
+    pub(crate) fn with_backref(self, context: Selector) -> SelectorCtx {
+        SelectorCtx::from(self).inside(&SelectorCtx {
+            s: Selectors::root(),
+            backref: context.clone(),
         })
     }
     /// Return true if any of these selectors ends with a combinator
@@ -169,6 +184,69 @@ impl From<Selectors> for Value {
     }
 }
 
+/// A full set of selectors with a separate backref.
+#[derive(Clone, Debug, PartialEq, Eq, PartialOrd)]
+pub struct SelectorCtx {
+    /// The actual selectors.
+    s: Selectors,
+    backref: Selector,
+}
+
+impl SelectorCtx {
+    /// Create a root (empty) selector.
+    pub fn root() -> Self {
+        Selectors::root().into()
+    }
+    pub(crate) fn root_with_backref(context: Selector) -> Self {
+        SelectorCtx {
+            s: Selectors::root(),
+            backref: context,
+        }
+    }
+    /// Return true if this is a root (empty) selector.
+    pub fn is_root(&self) -> bool {
+        self.s.is_root() && self.backref == Selector::root()
+    }
+
+    pub(crate) fn real(&self) -> Selectors {
+        self.s.clone()
+    }
+
+    /// Remove the first of these selectors (or the root selector if empty).
+    pub(crate) fn one(&self) -> Selector {
+        self.s.one()
+    }
+
+    /// Create the full selector for when self is used inside a parent selector.
+    pub(crate) fn inside(&self, parent: &Self) -> Self {
+        let mut result = Vec::new();
+        for p in &parent.s.s {
+            for s in &self.s.s {
+                result.push(p.join(s, &parent.backref));
+            }
+        }
+        SelectorCtx {
+            s: Selectors::new(result),
+            backref: parent.backref.clone(),
+        }
+    }
+}
+
+impl From<Selectors> for SelectorCtx {
+    fn from(value: Selectors) -> Self {
+        SelectorCtx {
+            s: value,
+            backref: Selector::root(),
+        }
+    }
+}
+
+impl TryFrom<Value> for SelectorCtx {
+    type Error = BadSelector;
+    fn try_from(v: Value) -> Result<Self, Self::Error> {
+        Selectors::try_from(v).map(Into::into)
+    }
+}
 impl TryFrom<Value> for Selectors {
     type Error = BadSelector;
     fn try_from(v: Value) -> Result<Self, Self::Error> {
@@ -186,10 +264,9 @@ fn value_to_selectors(v: &Value) -> Result<Selectors, BadSelector0> {
                 Ok(Selectors::new(vv))
             }
             Some(ListSeparator::Space) => {
-                let (mut outer, last) = vv.iter().fold(
-                    Result::<_, BadSelector0>::Ok((vec![], vec![])),
-                    |a, v: &Value| {
-                        let (mut outer, mut a) = a?;
+                let (mut outer, last) = vv.iter().try_fold(
+                    (vec![], vec![]),
+                    |(mut outer, mut a), v: &Value| {
                         if let Ok(ref mut s) = check_selector_str(v) {
                             push_descendant(&mut a, s);
                         } else {
@@ -203,7 +280,7 @@ fn value_to_selectors(v: &Value) -> Result<Selectors, BadSelector0> {
                             }
                             outer.extend(s.s);
                         }
-                        Ok((outer, a))
+                        Result::<_, BadSelector0>::Ok((outer, a))
                     },
                 )?;
                 outer.push(Selector(last));
@@ -257,7 +334,7 @@ fn push_descendant(to: &mut Vec<SelectorPart>, from: &mut Selector) {
     to.append(&mut from.0);
 }
 
-/// A css (or sass) selector.
+/// A single css selector.
 ///
 /// A selector does not contain `,`.  If it does, it is a `Selectors`,
 /// where each of the parts separated by the comma is a `Selector`.
@@ -290,19 +367,71 @@ impl Selector {
         }
     }
 
+    /// Validate that this selector is ok to use in css.
+    ///
+    /// `Selectors` can contain backref (`&`), but those must be
+    /// resolved before using the `Selectors` in css.
+    pub fn css_ok(self) -> Result<Self, BadSelector> {
+        if self.has_backref() {
+            let slf = self.to_string();
+            Err(BadSelector::Backref(input_span(slf)))
+        } else {
+            Ok(self)
+        }
+    }
+
     fn has_backref(&self) -> bool {
         self.0.iter().any(SelectorPart::has_backref)
     }
+
+    /// Return this selector without placeholders.
+    ///
+    /// For most plain selectors, this returns Some(clone of self).
+    /// For placeholder selectors, it returns None.
+    /// For some selectors containing e.g. `p:matches(%a,.foo)` it
+    /// returns a modified selector (in that case, `p:matches(.foo)`).
+    fn no_placeholder(&self) -> Option<Self> {
+        let v = self
+            .0
+            .iter()
+            .map(SelectorPart::no_placeholder)
+            .collect::<Option<Vec<_>>>()?;
+        let mut v2 = Vec::with_capacity(v.len());
+        let mut has_sel = false;
+        for part in v {
+            if has_sel && part.is_wildcard() {
+                continue;
+            }
+            has_sel = !part.is_operator();
+            v2.push(part);
+        }
+        let result = Selector(v2);
+        if result.has_trailing_combinator() || result.has_double_combinator()
+        {
+            None
+        } else {
+            Some(result)
+        }
+    }
+    fn has_leading_combinator(&self) -> bool {
+        matches!(self.0.first(), Some(SelectorPart::RelOp(_)))
+    }
     /// Return true if this selector ends with a combinator
     pub fn has_trailing_combinator(&self) -> bool {
         matches!(self.0.last(), Some(SelectorPart::RelOp(_)))
     }
+    fn has_double_combinator(&self) -> bool {
+        self.0.windows(2).any(|w| {
+            matches!(w, [SelectorPart::RelOp(_), SelectorPart::RelOp(_)])
+        })
+    }
 }
 
-impl TryInto<Selector> for Value {
+impl TryFrom<Value> for Selector {
     type Error = BadSelector;
-    fn try_into(self) -> Result<Selector, Self::Error> {
-        value_to_selector(&self).map_err(move |e| e.ctx(self))
+
+    fn try_from(value: Value) -> Result<Self, Self::Error> {
+        value_to_selector(&value).map_err(move |e| e.ctx(value))
     }
 }
 // Internal, the api is try_into.
@@ -324,17 +453,18 @@ fn value_to_selector(v: &Value) -> Result<Selector, BadSelector0> {
 }
 
 fn list_to_selector(list: &[Value]) -> Result<Selector, BadSelector0> {
-    Ok(Selector(list.iter().fold(
-        Result::<_, BadSelector0>::Ok(vec![]),
-        |a, v| {
-            let mut a = a?;
-            if !a.is_empty() {
+    list.iter()
+        .try_fold(vec![], |mut a, v| {
+            let parts = value_to_selector_parts(v)?;
+            if !parts.first().map_or(true, SelectorPart::is_operator)
+                && !a.last().map_or(true, SelectorPart::is_operator)
+            {
                 a.push(SelectorPart::Descendant);
             }
-            a.push(value_to_selector_part(v)?);
+            a.extend(parts);
             Ok(a)
-        },
-    )?))
+        })
+        .map(Selector)
 }
 
 /// A selector consist of a sequence of these parts.
@@ -351,6 +481,7 @@ pub enum SelectorPart {
     /// An attribute selector
     Attribute {
         /// The attribute name
+        // TODO: Why not a raw String?
         name: CssString,
         /// An operator
         op: String,
@@ -408,6 +539,56 @@ impl SelectorPart {
                 .map_or(false, |a| a.s.iter().any(Selector::has_backref)),
         }
     }
+    /// Return this selectorpart without placeholders.
+    ///
+    /// For most parts, this returns either Some(clone of self) or None if
+    /// it was a placeholder selector, but some pseudoselectors are
+    /// converted to a version without the placeholder parts.
+    fn no_placeholder(&self) -> Option<Self> {
+        match self {
+            SelectorPart::Simple(s) => {
+                if !s.starts_with('%') {
+                    Some(SelectorPart::Simple(s.clone()))
+                } else {
+                    None
+                }
+            }
+            SelectorPart::Pseudo { name, arg } => match name.value() {
+                "is" => arg
+                    .as_ref()
+                    .and_then(Selectors::no_placeholder)
+                    .and_then(Selectors::no_leading_combinator)
+                    .map(|arg| SelectorPart::Pseudo {
+                        name: name.clone(),
+                        arg: Some(arg),
+                    }),
+                "matches" | "any" | "where" | "has" => arg
+                    .as_ref()
+                    .and_then(Selectors::no_placeholder)
+                    .map(|arg| SelectorPart::Pseudo {
+                        name: name.clone(),
+                        arg: Some(arg),
+                    }),
+                "not" => {
+                    if let Some(arg) =
+                        arg.as_ref().and_then(Selectors::no_placeholder)
+                    {
+                        Some(SelectorPart::Pseudo {
+                            name: name.clone(),
+                            arg: Some(arg),
+                        })
+                    } else {
+                        Some(SelectorPart::Simple("*".into()))
+                    }
+                }
+                _ => Some(SelectorPart::Pseudo {
+                    name: name.clone(),
+                    arg: arg.clone(),
+                }),
+            },
+            x => Some(x.clone()),
+        }
+    }
     fn clone_in(&self, context: &Selector) -> Vec<SelectorPart> {
         match self {
             s @ (SelectorPart::Descendant
@@ -419,9 +600,9 @@ impl SelectorPart {
                 vec![SelectorPart::PseudoElement {
                     name: name.clone(),
                     arg: arg.as_ref().map(|a| {
-                        a.inside(
-                            &Selectors::root().with_backref(context.clone()),
-                        )
+                        a.inside(&SelectorCtx::root_with_backref(
+                            context.clone(),
+                        ))
                     }),
                 }]
             }
@@ -429,9 +610,9 @@ impl SelectorPart {
                 vec![SelectorPart::Pseudo {
                     name: name.clone(),
                     arg: arg.as_ref().map(|a| {
-                        a.inside(
-                            &Selectors::root().with_backref(context.clone()),
-                        )
+                        a.inside(&SelectorCtx::root_with_backref(
+                            context.clone(),
+                        ))
                     }),
                 }]
             }
@@ -439,15 +620,11 @@ impl SelectorPart {
     }
 }
 
-impl TryInto<SelectorPart> for Value {
-    type Error = BadSelector;
-    fn try_into(self) -> Result<SelectorPart, Self::Error> {
-        value_to_selector_part(&self).map_err(move |e| e.ctx(self))
-    }
-}
-fn value_to_selector_part(v: &Value) -> Result<SelectorPart, BadSelector0> {
+fn value_to_selector_parts(
+    v: &Value,
+) -> Result<Vec<SelectorPart>, BadSelector0> {
     match v {
-        Value::Literal(s) => Ok(ParseError::check(selector_part(
+        Value::Literal(s) => Ok(ParseError::check(selector_parts(
             input_span(s.value()).borrow(),
         ))?),
         _ => Err(BadSelector0::Value),
