@@ -69,9 +69,7 @@ impl CssString {
     }
     /// If the value is name-like, make it unquoted.
     pub fn opt_unquote(self) -> Self {
-        let mut chars = self.value.chars();
-        let t = chars.next().map_or(false, char::is_alphabetic)
-            && chars.all(|c| c.is_alphanumeric() || c == '-');
+        let t = is_namelike(&self.value);
         CssString {
             value: self.value,
             quotes: if t { Quotes::None } else { self.quotes },
@@ -118,12 +116,20 @@ impl CssString {
     pub fn is_null(&self) -> bool {
         self.value.is_empty() && self.quotes.is_none()
     }
+    pub(crate) fn is_name(&self) -> bool {
+        self.quotes == Quotes::None && is_namelike(&self.value)
+    }
+
     /// Return true if this is a css special function call.
     pub(crate) fn is_css_fn(&self) -> bool {
         let value = self.value();
         self.quotes() == Quotes::None
-            && value.ends_with(')')
-            && (value.starts_with("calc(") || value.starts_with("var("))
+            && (value.ends_with(')')
+                && (value.starts_with("calc(") || value.starts_with("var(")))
+            // The following is only relevant in relative colors
+            // but I don't see how to get that context to where its needed,
+            // and I don't see any real harm in puttin them like this.
+            || ["h", "s", "l", "r", "g", "b"].iter().any(|s| value == *s)
     }
     /// Return true if this is a css special function call.
     pub(crate) fn is_css_calc(&self) -> bool {
@@ -205,7 +211,17 @@ impl From<CssString> for crate::sass::Name {
     }
 }
 
+fn is_namelike(s: &str) -> bool {
+    let mut chars = s.chars();
+    chars
+        .next()
+        .map_or(false, |c| c.is_alphabetic() || c == '_')
+        && chars.all(|c| c.is_alphanumeric() || c == '-' || c == '_')
+}
+
 fn is_private_use(c: char) -> bool {
     // https://en.wikipedia.org/wiki/Private_Use_Areas
-    matches!(c as u32, 0xE000..=0xF8FF | 0xF0000..=0xFFFFD | 0x100000..=0x10FFFD)
+    ('\u{E000}'..='\u{F8FF}').contains(&c)
+        || ('\u{F0000}'..='\u{FFFFD}').contains(&c)
+        || ('\u{100000}'..='\u{10FFFD}').contains(&c)
 }
