@@ -1,3 +1,4 @@
+use super::util::IsNot;
 use super::{is_calc_name, is_not, BinOp, CallArgs, CssString};
 use crate::ordermap::OrderMap;
 use crate::output::{Format, Formatted};
@@ -97,10 +98,15 @@ impl Value {
         match *self {
             ref v if v.is_calculation() => "calculation",
             Value::ArgList(..) => "arglist",
-            Value::Call(..) => "string",
+            Value::Call(ref f, _) => {
+                if f == "var" {
+                    "variable"
+                } else {
+                    "string"
+                }
+            }
             Value::Color(..) => "color",
-            Value::Literal(..) => "string",
-            Value::BinOp(_) => "string",
+            Value::Literal(..) | Value::BinOp(_) => "string",
             Value::Map(..) => "map",
             Value::Numeric(..) => "number",
             Value::List(..) => "list",
@@ -130,8 +136,8 @@ impl Value {
     }
 
     fn needs_calc(&self) -> bool {
-        if let Value::Numeric(Numeric { value, unit: _ }, _) = self {
-            !value.is_finite()
+        if let Value::Numeric(Numeric { value, unit }, _) = self {
+            !value.is_finite() || !unit.valid_in_css()
         } else {
             false
         }
@@ -266,11 +272,7 @@ impl Value {
     }
     /// Format this value for error messages.
     pub fn introspect(&self) -> String {
-        // Note: The replaceing here is a silly workaround for
-        // https://github.com/sass/sass-spec/issues/1905
         self.to_string(Format::introspect())
-            .replace("infinity * 1", "Infinity")
-            .replace("NaN * 1", "NaN")
     }
 }
 
@@ -376,12 +378,12 @@ impl TryFrom<Value> for Color {
 }
 
 impl TryFrom<Value> for Numeric {
-    type Error = String;
+    type Error = IsNot;
 
     fn try_from(value: Value) -> Result<Self, Self::Error> {
         match value {
             Value::Numeric(num, ..) => Ok(num),
-            v => Err(is_not(&v, "a number")),
+            v => Err(IsNot::new(v, "a number")),
         }
     }
 }
@@ -439,8 +441,8 @@ impl std::fmt::Display for InvalidCss {
             InvalidCss::Incompat(a, b) => write!(
                 f,
                 "{} and {} have incompatible units.",
-                a.format(Format::introspect()),
-                b.format(Format::introspect()),
+                Value::from(a.clone()).introspect(),
+                Value::from(b.clone()).introspect(),
             ),
         }
     }
