@@ -1,6 +1,6 @@
-use super::Value;
+use super::{CallArgs, Value};
 use crate::output::Formatted;
-use crate::value::{ListSeparator, Operator};
+use crate::value::{ListSeparator, Numeric, Operator};
 use std::fmt::{self, Display, Write};
 
 impl<'a> Display for Formatted<'a, Value> {
@@ -80,7 +80,13 @@ impl<'a> Display for Formatted<'a, Value> {
                 Ok(())
             }
             Value::Call(ref name, ref arg) => {
-                write!(out, "{name}({arg})")
+                // TODO: Converting calc(1px) to 1px should probably be done earlier.
+                // it is for scss, but not when loading plain css.
+                if let Some(arg) = is_calc_result(name, arg) {
+                    write!(out, "{}", arg.format(self.format))
+                } else {
+                    write!(out, "{name}({arg})")
+                }
             }
             Value::BinOp(ref op) => op.format(self.format).fmt(out),
             Value::UnaryOp(ref op, ref v) => {
@@ -157,3 +163,15 @@ impl<'a> Display for Formatted<'a, Value> {
         }
     }
 }
+
+/// If a css `calc` can be evaluated to a static numerical result, return that value.
+fn is_calc_result<'a>(name: &str, arg: &'a CallArgs) -> Option<&'a Numeric> {
+    if name == "calc" {
+        arg.get_single().ok().and_then(|a| match a {
+            Value::Numeric(n, _) if n.unit.valid_in_css() => Some(n),
+            _ => None,
+        })
+    } else {
+        None
+    }
+}
