@@ -3,7 +3,7 @@
 
 use super::cssdest::CssDestination;
 use super::CssData;
-use crate::css::{self, AtRule, Import, Selectors};
+use crate::css::{self, AtRule, Import, SelectorCtx};
 use crate::error::ResultPos;
 use crate::input::{Context, Loader, Parsed, SourceKind};
 use crate::sass::{get_global_module, Expose, Item, UseAs};
@@ -152,7 +152,7 @@ fn handle_item(
                                 let selectors = scope.get_selectors();
                                 if !selectors.is_root() {
                                     let mut rule = thead
-                                        .start_rule(selectors.clone())
+                                        .start_rule(selectors.real())
                                         .at(pos)?;
                                     handle_body(
                                         &items,
@@ -207,7 +207,7 @@ fn handle_item(
                 .with_backref(scope.get_selectors().one());
             let subscope = ScopeRef::sub_selectors(scope, selectors.clone());
             if !selectors.is_root() {
-                let mut rule = dest.start_rule(selectors).no_pos()?;
+                let mut rule = dest.start_rule(selectors.real()).no_pos()?;
                 handle_body(body, &mut rule, subscope, file_context)?;
             } else {
                 handle_body(body, dest, subscope, file_context)?;
@@ -232,7 +232,7 @@ fn handle_item(
             if let Some(ref body) = *body {
                 let mut atrule = dest.start_atrule(name.clone(), args);
                 let local = if name == "keyframes" {
-                    ScopeRef::sub_selectors(scope, Selectors::root())
+                    ScopeRef::sub_selectors(scope, SelectorCtx::root())
                 } else {
                     ScopeRef::sub(scope)
                 };
@@ -358,9 +358,9 @@ fn handle_item(
 
         Item::Rule(ref selectors, ref body) => {
             check_body(body, BodyContext::Rule)?;
-            let selectors =
-                selectors.eval(scope.clone())?.inside(scope.get_selectors());
-            let mut dest = dest.start_rule(selectors.clone()).no_pos()?;
+            let selectors = SelectorCtx::from(selectors.eval(scope.clone())?)
+                .inside(scope.get_selectors());
+            let mut dest = dest.start_rule(selectors.real()).no_pos()?;
             let scope = ScopeRef::sub_selectors(scope, selectors);
             handle_body(body, &mut dest, scope, file_context)?;
         }
