@@ -4,7 +4,7 @@ mod selectors;
 mod strings;
 mod values;
 
-pub(crate) use self::selectors::{selector, selector_part, selectors};
+pub(crate) use self::selectors::{selector, selector_parts, selectors};
 
 use super::util::{opt_spacelike, spacelike};
 use super::{PResult, Span};
@@ -52,7 +52,7 @@ fn top_level_item(input: Span) -> PResult<Item> {
                         delimited(
                             terminated(tag("{"), opt_spacelike),
                             many0(terminated(
-                                alt((into(comment), into(rule::rule))),
+                                map_res(top_level_item, TryInto::try_into),
                                 opt_spacelike,
                             )),
                             tag("}"),
@@ -67,6 +67,7 @@ fn top_level_item(input: Span) -> PResult<Item> {
                     let (input, body) = preceded(
                         opt_spacelike,
                         alt((
+                            map(tag(";"), |_| None),
                             map(
                                 delimited(
                                     terminated(tag("{"), opt_spacelike),
@@ -86,7 +87,6 @@ fn top_level_item(input: Span) -> PResult<Item> {
                                 ),
                                 Some,
                             ),
-                            map(tag(";"), |_| None),
                         )),
                     )(input)?;
                     Ok((
@@ -114,13 +114,13 @@ fn import2(input: Span) -> PResult<Import> {
 
 // Arguments for unknwn at-rules.  Should probably be more permitting.
 fn atrule_args(input: Span) -> PResult<Span> {
-    recognize(preceded(
+    recognize(opt(preceded(
         is_not("()/{}"),
         opt(terminated(
             delimited(tag("("), atrule_args, tag(")")),
             atrule_args,
         )),
-    ))(input)
+    )))(input)
 }
 
 pub fn comment(input: Span) -> PResult<Comment> {
