@@ -6,7 +6,9 @@ use super::strings::{
 };
 use super::unit::unit;
 use super::util::{ignore_comments, opt_spacelike, spacelike2};
-use super::{input_to_string, position, sass_string, PResult, Span};
+use super::{
+    input_to_string, list_or_single, position, sass_string, PResult, Span,
+};
 use crate::sass::{BinOp, SassString, Value};
 use crate::value::{ListSeparator, Number, Numeric, Operator, Rgba};
 use nom::branch::alt;
@@ -60,14 +62,7 @@ pub fn space_list(input: Span) -> PResult<Value> {
             list
         },
     )(input)?;
-    Ok((
-        input,
-        if list.len() == 1 {
-            list.into_iter().next().unwrap()
-        } else {
-            Value::List(list, Some(ListSeparator::Space), false)
-        },
-    ))
+    Ok((input, list_or_single(list, ListSeparator::Space)))
 }
 
 pub fn simple_space_list(input: Span) -> PResult<Value> {
@@ -80,14 +75,7 @@ pub fn simple_space_list(input: Span) -> PResult<Value> {
             list
         },
     )(input)?;
-    Ok((
-        input,
-        if list.len() == 1 {
-            list.into_iter().next().unwrap()
-        } else {
-            Value::List(list, Some(ListSeparator::Space), false)
-        },
-    ))
+    Ok((input, list_or_single(list, ListSeparator::Space)))
 }
 
 fn se_or_ext_string(input: Span) -> PResult<Value> {
@@ -154,8 +142,8 @@ where
 {
     let (rest, v) = term(input)?;
     fold_many0(
-        tuple((
-            verify(
+        verify(
+            tuple((
                 tuple((
                     ignore_comments,
                     alt((
@@ -164,11 +152,16 @@ where
                     )),
                     ignore_comments,
                 )),
-                |(s1, op, s2)| op == &Operator::Plus || !*s1 || *s2,
-            ),
-            term,
-            position,
-        )),
+                term,
+                position,
+            )),
+            |((s1, op, s2), t2, _)| {
+                use Value::*;
+                *s2 || !*s1
+                    || op == &Operator::Plus
+                    || !matches!(&t2, Literal(_) | Numeric(_) | BinOp(_))
+            },
+        ),
         move || v.clone(),
         |v, ((s1, op, s2), v2, end)| {
             let pos = input.up_to(&end).to_owned();
@@ -210,80 +203,32 @@ where
 }
 
 pub fn single_value(input: Span) -> PResult<Value> {
-    if let Ok((input0, _p)) = preceded(tag("("), opt_spacelike)(input) {
-        if let Ok((input, first_key)) = simple_space_list(input0) {
-            let (input, value) = if let Ok((mut input, first_val)) =
-                preceded(colon, space_list)(input)
-            {
-                let mut items = vec![(first_key, first_val)];
-                while let Ok((rest, (key, val))) = pair(
-                    preceded(comma, simple_space_list),
-                    preceded(colon, space_list),
-                )(input)
-                {
-                    items.push((key, val));
-                    input = rest;
-                }
-                let (input, _) = opt(comma)(input)?;
-                (input, Value::Map(items))
-            } else {
-                (input, Value::Paren(Box::new(first_key), false))
-            };
-            if let Ok((input, _)) = end_paren(input) {
-                return Ok((input, value));
-            }
-        }
-        terminated(fallback_in_paren, end_paren)(input0)
-    } else {
-        simple_value(input)
+    match input.first() {
+        Some(b'!') => bang(input),
+        Some(b'&') => value(Value::HereSelector, tag("&"))(input),
+        Some(b'"') => map(sass_string_dq, Value::Literal)(input),
+        Some(b'\'') => map(sass_string_sq, Value::Literal)(input),
+        Some(b'[') => bracket_list(input),
+        Some(b'(') => value_in_parens(input),
+        _ => alt((
+            value(Value::True, tag("true")),
+            value(Value::False, tag("false")),
+            unicode_range,
+            into(numeric),
+            variable,
+            hex_color,
+            value(Value::Null, tag("null")),
+            map(special_url, Value::Literal),
+            special_function,
+            // Really ugly special case ... sorry.
+            value(Value::Literal("-null".into()), tag("-null")),
+            map(var_name, Value::Literal),
+            unary_op,
+            function_call_or_string,
+        ))(input),
     }
 }
 
-fn comma(input: Span) -> PResult<Span> {
-    delimited(opt_spacelike, tag(","), opt_spacelike)(input)
-}
-
-fn colon(input: Span) -> PResult<Span> {
-    delimited(opt_spacelike, tag(":"), opt_spacelike)(input)
-}
-
-fn fallback_in_paren(input: Span) -> PResult<Value> {
-    alt((
-        map(value_expression, |v| Value::Paren(Box::new(v), false)),
-        value(Value::List(vec![], None, false), tag("")),
-    ))(input)
-}
-
-fn end_paren(input: Span) -> PResult<Span> {
-    preceded(opt_spacelike, tag(")"))(input)
-}
-
-fn simple_value(input: Span) -> PResult<Value> {
-    alt((
-        bang,
-        value(Value::True, tag("true")),
-        value(Value::False, tag("false")),
-        value(Value::HereSelector, tag("&")),
-        unicode_range,
-        bracket_list,
-        into(numeric),
-        variable,
-        hex_color,
-        value(Value::Null, tag("null")),
-        map(special_url, Value::Literal),
-        special_function,
-        // Really ugly special case ... sorry.
-        value(Value::Literal("-null".into()), tag("-null")),
-        map(var_name, Value::Literal),
-        unary_op,
-        function_call,
-        // And a bunch of string variants
-        map(sass_string, literal_or_color),
-        map(sass_string_dq, Value::Literal),
-        map(sass_string_sq, Value::Literal),
-    ))(input)
-}
-
 fn bang(input: Span) -> PResult<Value> {
     map(
         map_res(
@@ -297,20 +242,65 @@ fn bang(input: Span) -> PResult<Value> {
     )(input)
 }
 
+pub fn value_in_parens(input: Span) -> PResult<Value> {
+    let (input0, _p) = preceded(tag("("), opt_spacelike)(input)?;
+    if let Ok((input, first_key)) = simple_space_list(input0) {
+        let (input, value) = if let Ok((mut input, first_val)) =
+            preceded(colon, space_list)(input)
+        {
+            let mut items = vec![(first_key, first_val)];
+            while let Ok((rest, (key, val))) = pair(
+                preceded(comma, simple_space_list),
+                preceded(colon, space_list),
+            )(input)
+            {
+                items.push((key, val));
+                input = rest;
+            }
+            let (input, _) = opt(comma)(input)?;
+            (input, Value::Map(items))
+        } else {
+            (input, Value::Paren(Box::new(first_key), false))
+        };
+        if let Ok((input, _)) = end_paren(input) {
+            return Ok((input, value));
+        }
+    }
+    terminated(
+        alt((
+            map(value_expression, |v| Value::Paren(Box::new(v), false)),
+            map(tag(""), |_| Value::List(vec![], None, false)),
+        )),
+        end_paren,
+    )(input0)
+}
+
+fn comma(input: Span) -> PResult<Span> {
+    delimited(opt_spacelike, tag(","), opt_spacelike)(input)
+}
+
+fn colon(input: Span) -> PResult<Span> {
+    delimited(opt_spacelike, tag(":"), opt_spacelike)(input)
+}
+
+fn end_paren(input: Span) -> PResult<Span> {
+    preceded(opt_spacelike, tag(")"))(input)
+}
+
 fn unicode_range(input: Span) -> PResult<Value> {
+    map(unicode_range_inner, Value::UnicodeRange)(input)
+}
+pub(crate) fn unicode_range_inner(input: Span) -> PResult<String> {
     let (rest, _) = tag_no_case("U+")(input)?;
     let (rest, a) = many_m_n(0, 6, one_of("0123456789ABCDEFabcdef"))(rest)?;
     let (rest, _) = alt((
         preceded(tag("-"), many_m_n(1, 6, one_of("0123456789ABCDEFabcdef"))),
         many_m_n(0, 6 - a.len(), one_of("?")),
     ))(rest)?;
-    let length = input.fragment().len() - rest.fragment().len();
+    let length = rest.location_offset() - input.location_offset();
     let matched = &input.fragment()[0..length];
-    Ok((
-        rest,
-        // The unwrap should be ok, as only ascii is matched.
-        Value::UnicodeRange(from_utf8(matched).unwrap().to_string()),
-    ))
+    // The unwrap should be ok, as only ascii is matched.
+    Ok((rest, from_utf8(matched).unwrap().to_string()))
 }
 
 pub fn bracket_list(input: Span) -> PResult<Value> {
@@ -366,7 +356,8 @@ pub fn number(input: Span) -> PResult<Number> {
             };
             if let Some((e_sign, e_val)) = exp {
                 let e_val = if e_sign == Some(b"-") { -e_val } else { e_val };
-                value * Number::from(10f64.powi(e_val))
+                // Note: powi sounds right, but looses some precision.
+                value * Number::from(10f64.powf(e_val.into()))
             } else {
                 value
             }
@@ -449,19 +440,27 @@ fn hex_color(input: Span) -> PResult<Value> {
 
 pub fn unary_op(input: Span) -> PResult<Value> {
     map(
-        pair(
-            terminated(
-                alt((
-                    value(Operator::Plus, tag("+")),
-                    value(Operator::Minus, tag("-")),
-                    value(Operator::Div, terminated(tag("/"), spacelike2)),
-                    value(Operator::Not, terminated(tag("not"), spacelike2)),
-                )),
-                opt_spacelike,
-            ),
+        tuple((
+            alt((
+                value(Operator::Plus, tag("+")),
+                value(Operator::Minus, tag("-")),
+                value(Operator::Div, terminated(tag("/"), spacelike2)),
+                value(Operator::Not, terminated(tag("not"), spacelike2)),
+            )),
+            ignore_comments,
             single_value,
-        ),
-        |(op, v)| Value::UnaryOp(op, Box::new(v)),
+        )),
+        |(op, s, v)| match (op, s, v) {
+            (
+                Operator::Minus | Operator::Plus,
+                false,
+                Value::Literal(mut s),
+            ) if s.is_unquoted() => {
+                s.prepend(&op.to_string());
+                Value::Literal(s)
+            }
+            (op, _, v) => Value::UnaryOp(op, Box::new(v)),
+        },
     )(input)
 }
 
@@ -470,14 +469,33 @@ pub fn special_function(input: Span) -> PResult<Value> {
     alt((css_function, map(special_function_misc, Value::Literal)))(input)
 }
 
-pub fn function_call(input: Span) -> PResult<Value> {
-    let (rest, (name, args)) = pair(sass_string, call_args)(input)?;
-    let pos = input.up_to(&rest).to_owned();
-    Ok((rest, Value::Call(name, args, pos)))
+pub fn function_call_or_string(input: Span) -> PResult<Value> {
+    let (rest, name) = sass_string(input)?;
+    /* TODO: true, false and null should end up here, but can't as long as '.' is a normal part of a string.
+    if let Some(special) = name.single_raw().and_then(|s| match s {
+        "true" => return Some(Value::True),
+        "false" => return Some(Value::False),
+        "null" => return Some(Value::Null),
+        _ => None,
+    }) {
+        return Ok((rest, special));
+    }
+     */
+    if let Ok((rest, args)) = call_args(rest) {
+        let pos = input.up_to(&rest).to_owned();
+        return Ok((rest, Value::Call(name, args, pos)));
+    }
+    Ok((rest, literal_or_color(name)))
 }
 
 fn literal_or_color(s: SassString) -> Value {
     if let Some(val) = s.single_raw() {
+        if val == "infinity" {
+            return Value::scalar(f64::INFINITY);
+        }
+        if val == "NaN" {
+            return Value::scalar(f64::NAN);
+        }
         if let Some(rgba) = Rgba::from_name(val) {
             return Value::Color(rgba, Some(val.to_string()));
         }
