@@ -1,8 +1,8 @@
 use super::{Call, Closure, FormalArgs, Name};
 use crate::css::{self, is_not, BinOp, CallArgs, CssString, Value};
 use crate::input::SourcePos;
-use crate::output::{Format, Formatted};
-use crate::value::{CssDimension, Operator, Quotes};
+use crate::output::Format;
+use crate::value::{CssDimensionSet, Numeric, Operator, Quotes};
 use crate::{Scope, ScopeRef};
 use lazy_static::lazy_static;
 use std::collections::BTreeMap;
@@ -118,7 +118,11 @@ impl Functions for Scope {
 impl Function {
     /// Get a built-in function by name.
     pub fn get_builtin(name: &Name) -> Option<&'static Function> {
-        FUNCTIONS.get(name)
+        FUNCTIONS.get(name).or_else(|| {
+            // Builtin function names are caseless.
+            let name = name.as_ref().to_lowercase();
+            FUNCTIONS.get(&name.into())
+        })
     }
 
     /// Create a new `Function` from a rust implementation.
@@ -217,21 +221,6 @@ lazy_static! {
                     _ => false,
                 }
             }
-            // Note: None here is for unknown, e.g. the dimension of something that is not a number.
-            fn css_dim(v: &Value) -> Option<Vec<(CssDimension, i8)>> {
-                match v {
-                    // TODO: Handle BinOp recursively (again) (or let in_calc return (Value, CssDimension)?)
-                    Value::Numeric(num, _) => {
-                        let u = &num.unit;
-                        if u.is_known() && !u.is_percent() {
-                            Some(u.css_dimension())
-                        } else {
-                            None
-                        }
-                    }
-                    _ => None,
-                }
-            }
             fn do_eval(v: Value) -> Result<Value, CallError> {
                 match v {
                     Value::Literal(s) if s.quotes() == Quotes::None => {
@@ -256,15 +245,14 @@ lazy_static! {
                         }
                     }
                     Value::Call(name, args) => {
-                        if name == "calc"
-                            && args.check_no_named().is_ok()
-                            && args.positional.len() == 1
-                        {
-                            let arg =
-                                args.positional.into_iter().next().unwrap();
-                            Ok(Value::Paren(Box::new(
-                                do_eval(arg)?,
-                            )))
+                        if name == "calc" {
+                            let arg = args.get_single().unwrap();
+                            match do_eval(arg.clone())? {
+                                Value::Literal(s) if s.is_name() => {
+                                    Ok(s.into())
+                                }
+                                arg => Ok(Value::Paren(Box::new(arg))),
+                            }
                         } else {
                             Ok(Value::Call(name, args))
                         }
@@ -273,75 +261,42 @@ lazy_static! {
                         let a = do_eval(op.a().clone())?;
                         let b = do_eval(op.b().clone())?;
                         let op = op.op();
-                        if let Ok(Some(result)) = op.eval(a.clone(), b.clone()) {
+                        if let Ok(Some(result)) =
+                            op.eval(a.clone(), b.clone())
+                        {
                             return Ok(result);
                         }
-                        Ok(BinOp::new(
-                            a,
-                            true,
-                            op,
-                            true,
-                            b,
-                        ).into())
-                    }
-                    Value::Numeric(num, c) => {
-                        Ok(Value::Numeric(num, c))
+                        Ok(BinOp::new(a, true, op, true, b).into())
                     }
+                    num @ Value::Numeric(..) => Ok(num),
                     Value::Paren(v) => match v.as_ref() {
                         l @ Value::Paren(_) => Ok(l.clone()),
                         l @ Value::BinOp(..) => Ok(l.clone()),
                         _ => Ok(Value::Paren(v)),
-                    }
-                    v => Err(CallError::msg(format!(
-                        "Value {} can't be used in a calculation.",
-                        v.format(Format::introspect())
-                    ))),
-                }
-            }
-            fn in_calc(v: Value) -> Result<Value, CallError> {
-                match v {
-                    Value::Literal(s) if s.quotes() == Quotes::None => {
-                        Ok(s.into())
-                    }
-                    Value::Call(name, args) => {
-                        Ok(Value::Call(name, args))
-                    }
-                    Value::BinOp(op) => {
-                        let a = in_calc(op.a().clone())?;
-                        let b = in_calc(op.b().clone())?;
-                        let op = op.op();
-                        if let (Some(adim), Some(bdim)) = (css_dim(&a), css_dim(&b)) {
-                            if (op == Operator::Plus || op == Operator::Minus) && adim != bdim {
-                                return Err(CallError::msg(format!(
-                                    "{} and {} are incompatible.",
-                                    a.format(Format::introspect()),
-                                    b.format(Format::introspect()),
-                                )))
+                    },
+                    Value::List(v, sep, bra) => {
+                        fn seems_numeric(v: &Value) -> bool {
+                            match v {
+                                Value::Numeric(..) => true,
+                                Value::Call(n, _) if n == "calc" => true,
+                                Value::Literal(s) => {
+                                    // FIXME: This requires more ops, and
+                                    // are still a silly way to do it.
+                                    s.quotes() == Quotes::None
+                                        && !s.value().starts_with('-')
+                                        && !s.value().starts_with('+')
+                                        && !s.value().ends_with('-')
+                                        && !s.value().ends_with('+')
+                                }
+                                _ => false,
                             }
                         }
-                        Ok(BinOp::new(
-                            a,
-                            true,
-                            op,
-                            true,
-                            b,
-                        ).into())
-                    }
-                    Value::Numeric(num, c) => {
-                        if num.unit.valid_in_css() {
-                            Ok(Value::Numeric(num, c))
+                        if v.windows(2).all(|p| p.iter().all(seems_numeric)) {
+                            Err(CallError::msg("Missing math operator."))
                         } else {
-                            Err(CallError::msg(format!(
-                                "Number {} isn't compatible with CSS calculations.",
-                                num.format(Format::introspect())
-                            )))
+                            Ok(Value::List(v, sep, bra))
                         }
                     }
-                    Value::Paren(v) => match v.as_ref() {
-                        l @ Value::Paren(_) => Ok(l.clone()),
-                        l @ Value::BinOp(..) => Ok(l.clone()),
-                        _ => Ok(Value::Paren(v)),
-                    }
                     v => Err(CallError::msg(format!(
                         "Value {} can't be used in a calculation.",
                         v.format(Format::introspect())
@@ -356,31 +311,10 @@ lazy_static! {
                     v => Ok(v),
                 }
             } else {
-                let arg = match in_calc(v)? {
-                    Value::Paren(arg) if !matches!(arg.as_ref(), Value::Call(..)) => *arg,
-                    arg => arg,
-                };
-                Ok(Value::Call(
-                    "calc".into(),
-                    CallArgs::from_single(arg),
-                ))
+                let arg = css_fn_arg(v)?;
+                Ok(Value::Call("calc".into(), CallArgs::from_single(arg)))
             }
         });
-        def!(f, clamp(min, number = b"null", max = b"null"), |s| {
-            self::math::clamp_fn(s).or_else(|_| {
-                let mut args = vec![s.get(name!(min))?];
-                if let Some(b) = s.get_opt(name!(number))? {
-                    args.push(b);
-                }
-                if let Some(c) = s.get_opt(name!(max))? {
-                    args.push(c);
-                }
-                Ok(css::Value::Call(
-                    "clamp".into(),
-                    css::CallArgs::from_list(args),
-                ))
-            })
-        });
         color::expose(MODULES.get("sass:color").unwrap(), &mut f);
         list::expose(MODULES.get("sass:list").unwrap(), &mut f);
         map::expose(MODULES.get("sass:map").unwrap(), &mut f);
@@ -392,6 +326,66 @@ lazy_static! {
     };
 }
 
+fn css_fn_arg(v: Value) -> Result<Value, CallError> {
+    match v {
+        Value::Literal(s) if s.quotes() == Quotes::None => Ok(s.into()),
+        Value::Call(name, args) => Ok(Value::Call(name, args)),
+        Value::BinOp(op) => {
+            let a = css_fn_arg(op.a().clone())?;
+            let b = css_fn_arg(op.b().clone())?;
+            let op = op.op();
+            if let (Some(adim), Some(bdim)) = (css_dim(&a), css_dim(&b)) {
+                if (op == Operator::Plus || op == Operator::Minus)
+                    && adim != bdim
+                {
+                    return Err(CallError::incompatible_values(&a, &b));
+                }
+            }
+            Ok(BinOp::new(a, true, op, true, b).into())
+        }
+        Value::Numeric(num, c) => {
+            if num.unit.valid_in_css() {
+                Ok(Value::Numeric(num, c))
+            } else {
+                Err(CallError::msg(format!(
+                    "Number {} isn't compatible with CSS calculations.",
+                    Value::Numeric(num, c).introspect()
+                )))
+            }
+        }
+        Value::Paren(v) => match v.as_ref() {
+            l @ Value::Paren(_) => Ok(l.clone()),
+            l @ Value::BinOp(..) => Ok(l.clone()),
+            _ => Ok(Value::Paren(v)),
+        },
+        list @ Value::List(..) => {
+            // FIXME: Check if list seems good, as above?
+            Ok(list)
+        }
+        v => Err(CallError::msg(format!(
+            "Value {} can't be used in a calculation.",
+            v.format(Format::introspect())
+        ))),
+    }
+}
+
+// Note: None here is for unknown, e.g. the dimension of something that is not a number.
+fn css_dim(v: &Value) -> Option<CssDimensionSet> {
+    match v {
+        // TODO: Handle BinOp recursively (again) (or let in_calc return (Value, CssDimension)?)
+        Value::Numeric(num, _) => known_dim(num),
+        _ => None,
+    }
+}
+fn known_dim(v: &Numeric) -> Option<CssDimensionSet> {
+    let u = &v.unit;
+    if u.is_known() && !u.is_percent() {
+        Some(u.css_dimension())
+    } else {
+        None
+    }
+}
+
 // argument helpers for the actual functions
 
 trait CheckedArg<T> {
@@ -403,18 +397,8 @@ impl<T, E: ToString> CheckedArg<T> for Result<T, E> {
     }
 }
 
-fn expected_to<'a, T>(value: &'a T, cond: &str) -> String
-where
-    Formatted<'a, T>: std::fmt::Display,
-{
-    format!(
-        "Expected {} to {}.",
-        Formatted {
-            value,
-            format: Format::introspect()
-        },
-        cond,
-    )
+fn expected_to<T: Into<Value>>(value: T, cond: &str) -> String {
+    format!("Expected {} to {}.", value.into().introspect(), cond)
 }
 
 fn is_special(v: &Value) -> bool {
@@ -449,7 +433,7 @@ mod check {
         if val.is_no_unit() {
             Ok(val.value)
         } else {
-            Err(expected_to(&val, "have no units"))
+            Err(expected_to(val, "have no units"))
         }
     }
     pub fn unitless_int(v: Value) -> Result<i64, String> {
