@@ -1,11 +1,15 @@
 use super::{check, CallError, FunctionMap, ResolvedArgs};
-use crate::css::{BadSelector, Selectors, Value};
+use crate::css::{BadSelector, LogicalSelectorSet, Selectors, Value};
 use crate::sass::Name;
 use crate::Scope;
 
 pub fn create_module() -> Scope {
     let mut f = Scope::builtin_module("sass:selector");
-    // TODO: is_superselector
+    def!(f, is_superselector(super, sub), |s| {
+        let sup: LogicalSelectorSet = s.get(name!(super))?;
+        let sub: LogicalSelectorSet = s.get(name!(sub))?;
+        Ok(sup.is_superselector(&sub).into())
+    });
     def_va!(f, append(selectors), |s| {
         let mut s = get_selectors(s, name!(selectors))?.into_iter();
         if let Some(base) = s.next() {
@@ -22,12 +26,24 @@ pub fn create_module() -> Scope {
     def_va!(f, nest(selectors), |s| {
         let mut v = get_selectors(s, name!(selectors))?.into_iter();
         let first = v.next().unwrap().css_ok()?;
-        Ok(v.fold(first, |b, e| e.inside(&b)).into())
+        Ok(v.fold(first, |b, e| e.inside(&b.into())).into())
     });
     def!(f, parse(selector), |s| {
         Ok(s.get_map(name!(selector), parse_selectors_x)?.into())
     });
-    // TODO: replace, unify, simple_selectors
+    def!(f, replace(selector, original, replacement), |s| {
+        let selector: LogicalSelectorSet = s.get(name!(selector))?;
+        let original: LogicalSelectorSet = s.get(name!(original))?;
+        let replacement: LogicalSelectorSet = s.get(name!(replacement))?;
+        Ok(selector.replace(&original, &replacement)?.into())
+    });
+    // TODO: simple_selectors
+    def!(f, unify(selector1, selector2), |s| {
+        let a: LogicalSelectorSet = s.get(name!(selector1))?;
+        let b: LogicalSelectorSet = s.get(name!(selector2))?;
+        Ok(a.unify(b).into())
+    });
+
     f
 }
 
@@ -44,13 +60,13 @@ fn get_selectors(
 pub fn expose(m: &Scope, global: &mut FunctionMap) {
     for (gname, lname) in &[
         // - - - Mixins - - -
-        //(name!(is_superselector), name!(is_superselector)),
+        (name!(is_superselector), name!(is_superselector)),
         (name!(selector_append), name!(append)),
         //(name!(selector_extend), name!(extend)),
         (name!(selector_nest), name!(nest)),
         (name!(selector_parse), name!(parse)),
-        //(name!(selector_replace), name!(replace)),
-        //(name!(selector_unify), name!(unify)),
+        (name!(selector_replace), name!(replace)),
+        (name!(selector_unify), name!(unify)),
         //(name!(simple_selectors), name!(simple_selectors)),
     ] {
         global.insert(gname.clone(), m.get_lfunction(lname));
