@@ -117,18 +117,43 @@ impl Mul for &NumValue {
     type Output = NumValue;
     fn mul(self, rhs: Self) -> NumValue {
         match (self, rhs) {
-            (NumValue::Rational(s), NumValue::Rational(r)) => s
-                .checked_mul(r)
-                .map(Into::into)
-                .unwrap_or_else(|| (biggen(s) * biggen(r)).into()),
+            (NumValue::Rational(s), NumValue::Rational(r)) => {
+                if (s.is_zero() && r.is_negative())
+                    || (r.is_zero() && s.is_negative())
+                {
+                    (-0.0).into()
+                } else {
+                    s.checked_mul(r)
+                        .map(Into::into)
+                        .unwrap_or_else(|| (biggen(s) * biggen(r)).into())
+                }
+            }
             (NumValue::Rational(s), NumValue::BigRational(r)) => {
-                (biggen(s) * r.as_ref()).into()
+                if (s.is_zero() && r.is_negative())
+                    || (r.is_zero() && s.is_negative())
+                {
+                    (-0.0).into()
+                } else {
+                    (biggen(s) * r.as_ref()).into()
+                }
             }
             (NumValue::BigRational(s), NumValue::Rational(r)) => {
-                (s.as_ref() * biggen(r)).into()
+                if (s.is_zero() && r.is_negative())
+                    || (r.is_zero() && s.is_negative())
+                {
+                    (-0.0).into()
+                } else {
+                    (s.as_ref() * biggen(r)).into()
+                }
             }
             (NumValue::BigRational(s), NumValue::BigRational(r)) => {
-                (s.as_ref() * r.as_ref()).into()
+                if (s.is_zero() && r.is_negative())
+                    || (r.is_zero() && s.is_negative())
+                {
+                    (-0.0).into()
+                } else {
+                    (s.as_ref() * r.as_ref()).into()
+                }
             }
             (NumValue::Float(s), r) => (s * f64::from(r)).into(),
             (s, NumValue::Float(r)) => (f64::from(s) * r).into(),
@@ -188,6 +213,13 @@ impl Rem for &NumValue {
         if rhs.is_zero() {
             return (f64::from(self) % 0.).into();
         }
+        fn float_rem(s: f64, r: f64) -> f64 {
+            if r.is_infinite() && s.signum() * r.signum() < 0. {
+                f64::NAN
+            } else {
+                s % r
+            }
+        }
         match (self, rhs) {
             (NumValue::Rational(s), NumValue::Rational(r)) => (s % r).into(),
             (NumValue::Rational(s), NumValue::BigRational(r)) => {
@@ -199,8 +231,8 @@ impl Rem for &NumValue {
             (NumValue::BigRational(s), NumValue::BigRational(r)) => {
                 (s.as_ref() % r.as_ref()).into()
             }
-            (NumValue::Float(s), r) => (s % f64::from(r)).into(),
-            (s, NumValue::Float(r)) => (f64::from(s) % r).into(),
+            (NumValue::Float(s), r) => float_rem(*s, r.into()).into(),
+            (s, NumValue::Float(r)) => float_rem(s.into(), *r).into(),
         }
     }
 }
@@ -214,7 +246,7 @@ impl Div for &NumValue {
     type Output = NumValue;
     fn div(self, rhs: Self) -> NumValue {
         if rhs.is_zero() {
-            return (f64::from(self) / 0.).into();
+            return (f64::from(self) / f64::from(rhs)).into();
         }
         match (self, rhs) {
             (NumValue::Rational(s), NumValue::Rational(r)) => s
@@ -345,6 +377,13 @@ impl NumValue {
             NumValue::Float(r) => r.floor().into(),
         }
     }
+    pub fn trunc(&self) -> NumValue {
+        match self {
+            NumValue::Rational(r) => r.trunc().into(),
+            NumValue::BigRational(r) => r.trunc().into(),
+            NumValue::Float(r) => r.trunc().into(),
+        }
+    }
     pub fn round(&self) -> NumValue {
         match self {
             NumValue::Rational(r) => r.round().into(),
@@ -352,6 +391,21 @@ impl NumValue {
             NumValue::Float(r) => r.round().into(),
         }
     }
+    pub fn signum(&self) -> NumValue {
+        match self {
+            NumValue::Rational(r) => r.signum().into(),
+            NumValue::BigRational(r) => r.signum().into(),
+            NumValue::Float(r) => {
+                // The sass spec says sign(-0) is -0
+                // ... which may be a bug, but here's to compatibility:
+                if r.is_zero() {
+                    (*r).into()
+                } else {
+                    r.signum().into()
+                }
+            }
+        }
+    }
     pub fn as_ratio(&self) -> Result<Rational, BadNumber> {
         match self {
             NumValue::Rational(r) => Ok(*r),
@@ -398,21 +452,33 @@ impl Number {
             value: self.value.ceil(),
         }
     }
-    /// Get a copy of this number, rounded towards zero.
+    /// Get a copy of this number, rounded down.
     pub fn floor(&self) -> Self {
         Number {
             value: self.value.floor(),
         }
     }
+    /// Get a copy of this number, rounded towards zero.
+    pub fn trunc(&self) -> Self {
+        Number {
+            value: self.value.trunc(),
+        }
+    }
     /// Get a copy of this number, rounded to nearest integer.
     pub fn round(&self) -> Self {
         Number {
             value: self.value.round(),
         }
     }
+    /// Get the sign of this number.
+    pub fn signum(&self) -> Self {
+        Number {
+            value: self.value.signum(),
+        }
+    }
     /// Computes the absolute value of the number, retaining the flags.
-    pub fn abs(self) -> Self {
-        match self.value {
+    pub fn abs(&self) -> Self {
+        match &self.value {
             NumValue::Rational(s) => s.abs().into(),
             NumValue::BigRational(s) => s.abs().into(),
             NumValue::Float(s) => s.abs().into(),
