@@ -136,18 +136,24 @@ impl Neg for &Numeric {
 impl Div for &Numeric {
     type Output = Numeric;
     fn div(self, rhs: Self) -> Self::Output {
+        let value = &self.value / &rhs.value;
+        let mut unit = &self.unit / &rhs.unit;
+        let scale = unit.simplify();
         Numeric {
-            value: &self.value / &rhs.value,
-            unit: &self.unit / &rhs.unit,
+            value: value * scale,
+            unit,
         }
     }
 }
 impl Mul for &Numeric {
     type Output = Numeric;
     fn mul(self, rhs: Self) -> Self::Output {
+        let value = &self.value * &rhs.value;
+        let mut unit = &self.unit * &rhs.unit;
+        let scale = unit.simplify();
         Numeric {
-            value: &self.value * &rhs.value,
-            unit: &self.unit * &rhs.unit,
+            value: value * scale,
+            unit,
         }
     }
 }
@@ -157,7 +163,7 @@ impl<'a> Display for Formatted<'a, Numeric> {
         let mut unit = self.value.unit.clone();
         let value = &self.value.value * &unit.simplify();
         value.format(self.format).fmt(out)?;
-        if !(unit.is_none() || value.is_finite()) {
+        if !value.is_finite() && unit.is_pos() {
             out.write_str(" * 1")?;
         }
         unit.fmt(out)
