@@ -23,6 +23,9 @@ impl UnitSet {
     pub fn is_none(&self) -> bool {
         self.units.iter().all(|(u, _)| *u == Unit::None)
     }
+    pub(crate) fn is_pos(&self) -> bool {
+        self.units.iter().any(|(u, p)| *u != Unit::None && *p > 0)
+    }
     /// Check if this `UnitSet` conains only known units.
     pub fn is_known(&self) -> bool {
         !self
@@ -46,40 +49,36 @@ impl UnitSet {
         use std::collections::BTreeMap;
         self.units
             .iter()
-            .fold(BTreeMap::new(), |mut map, (unit, power)| {
-                let dim = unit.dimension();
-                if dim != Dimension::None {
-                    *map.entry(unit.dimension()).or_insert(0) += *power;
-                }
+            .map(|(unit, p)| (unit.dimension(), p))
+            .filter(|(dim, _p)| *dim != Dimension::None)
+            .fold(BTreeMap::new(), |mut map, (dim, power)| {
+                *map.entry(dim).or_insert(0) += *power;
                 map
             })
             .into_iter()
             .filter(|(_d, power)| *power != 0)
-            .collect::<Vec<_>>()
+            .collect()
     }
 
-    pub(crate) fn css_dimension(&self) -> Vec<(CssDimension, i8)> {
+    pub(crate) fn css_dimension(&self) -> CssDimensionSet {
         use std::collections::BTreeMap;
-        self.units
+        let dim = self
+            .units
             .iter()
-            .fold(BTreeMap::new(), |mut map, (unit, power)| {
-                let dim = CssDimension::from(unit.dimension());
-                if dim != CssDimension::None {
-                    *map.entry(dim).or_insert(0) += *power;
-                }
+            .map(|(unit, p)| (CssDimension::from(unit.dimension()), p))
+            .filter(|(dim, _p)| *dim != CssDimension::None)
+            .fold(BTreeMap::new(), |mut map, (dim, power)| {
+                *map.entry(dim).or_insert(0) += *power;
                 map
             })
             .into_iter()
             .filter(|(_d, power)| *power != 0)
-            .collect::<Vec<_>>()
+            .collect();
+        CssDimensionSet { dim }
     }
+
     pub(crate) fn valid_in_css(&self) -> bool {
-        let dim = self.css_dimension();
-        match &dim[..] {
-            [] => true,
-            [(_d, p)] => *p == 1,
-            _ => false,
-        }
+        self.units.len() < 2 && self.css_dimension().valid_in_css()
     }
 
     /// Get a scaling factor to convert this unit to another unit.
@@ -192,41 +191,48 @@ impl From<Unit> for UnitSet {
 
 impl Display for UnitSet {
     fn fmt(&self, out: &mut fmt::Formatter) -> fmt::Result {
-        let pos: Vec<_> =
-            self.units.iter().filter(|(_u, p)| *p > 0).collect();
-        let neg: Vec<_> =
-            self.units.iter().filter(|(_u, p)| *p < 0).collect();
+        // "short" format is used (only?) by the math.units(..) function.
+        let short = out.alternate();
+        let mut pos = self.units.iter().filter(|(_u, p)| *p > 0);
+        let mut neg = self.units.iter().filter(|(_u, p)| *p < 0);
 
-        if let Some(((u, p), rest)) = pos.split_first() {
+        if let Some((u, p)) = pos.next() {
             write_one(out, u, *p)?;
-            for (u, p) in rest {
-                out.write_str("*")?;
+            for (u, p) in pos {
+                out.write_str(if short { "*" } else { " * 1" })?;
                 write_one(out, u, p.abs())?;
             }
-            if let Some(((u, p), rest)) = neg.split_first() {
-                out.write_str("/")?;
+            if let Some((u, p)) = neg.next() {
+                out.write_str(if short { "/" } else { " / 1" })?;
                 write_one(out, u, p.abs())?;
-                for (u, p) in rest {
-                    out.write_str("*")?;
+                for (u, p) in neg {
+                    out.write_str(if short { "*" } else { " / 1" })?;
                     write_one(out, u, p.abs())?;
                 }
             }
-        } else {
-            match neg.split_first() {
-                None => (),
-                Some(((u, p), [])) => {
+        } else if short {
+            match (neg.next(), neg.next()) {
+                (None, _) => (),
+                (Some((u, p)), None) => {
                     write_one(out, u, *p)?;
                 }
-                Some(((u, p), rest)) => {
+                (Some((u, p)), Some((nu, np))) => {
                     out.write_str("(")?;
                     write_one(out, u, p.abs())?;
-                    for (u, p) in rest {
+                    out.write_str("*")?;
+                    write_one(out, nu, np.abs())?;
+                    for (u, p) in neg {
                         out.write_str("*")?;
                         write_one(out, u, p.abs())?;
                     }
                     out.write_str(")^-1")?;
                 }
             }
+        } else {
+            for (u, p) in neg {
+                out.write_str(" / 1")?;
+                write_one(out, u, p.abs())?;
+            }
         }
         Ok(())
     }
@@ -236,7 +242,7 @@ fn write_one(out: &mut fmt::Formatter, u: &Unit, p: i8) -> fmt::Result {
     u.fmt(out)?;
     if (0..=3).contains(&p) {
         for _ in 1..p {
-            write!(out, "*{u}")?;
+            write!(out, " * 1{u}")?;
         }
     } else {
         write!(out, "^{p}")?;
@@ -250,3 +256,31 @@ impl fmt::Debug for UnitSet {
         out.debug_list().entries(&self.units).finish()
     }
 }
+
+/// The dimension of a numeric value.
+///
+/// May be e.g. lenght, or something complex like length^17*angle*time^-3.
+#[derive(Debug, Default, PartialEq, Eq)]
+pub struct CssDimensionSet {
+    dim: Vec<(CssDimension, i8)>,
+}
+impl CssDimensionSet {
+    /// Return true for the empty dimension, i.e. the dimension of a unitless number.
+    pub fn is_empty(&self) -> bool {
+        self.dim.is_empty()
+    }
+    /// Return true if any unknown unit is part of the dimension.
+    pub fn is_unknown(&self) -> bool {
+        self.dim
+            .iter()
+            .any(|(dim, _)| matches!(dim, CssDimension::Unknown(_)))
+    }
+
+    pub(crate) fn valid_in_css(&self) -> bool {
+        match &self.dim[..] {
+            [] => true,
+            [(_d, p)] => *p == 1,
+            _ => false,
+        }
+    }
+}
