@@ -1,5 +1,5 @@
 //! A scope is something that contains variable values.
-use crate::css::{CssString, Selectors, Value};
+use crate::css::{CssString, SelectorCtx, Value};
 use crate::input::SourcePos;
 use crate::output::Format;
 use crate::sass::{Expose, Function, Item, MixinDecl, Name, UseAs};
@@ -35,7 +35,7 @@ impl ScopeRef {
         Self::dynamic(Scope::sub(parent))
     }
     /// Create a new subscope of a given parent with selectors.
-    pub fn sub_selectors(parent: ScopeRef, selectors: Selectors) -> Self {
+    pub fn sub_selectors(parent: ScopeRef, selectors: SelectorCtx) -> Self {
         Self::dynamic(Scope::sub_selectors(parent, selectors))
     }
     fn dynamic(scope: Scope) -> Self {
@@ -134,8 +134,7 @@ impl ScopeRef {
                     let msg = value.evaluate(self)?.introspect();
                     return Err(Invalid::AtError(msg).at(pos.clone()));
                 }
-                Item::None => None,
-                Item::Comment(..) => None,
+                Item::None | Item::Comment(..) => None,
                 ref x => {
                     return Err(Error::S(format!(
                         "Not implemented in function: {x:?}",
@@ -209,7 +208,7 @@ pub struct Scope {
     variables: Mutex<BTreeMap<Name, Value>>,
     mixins: Mutex<BTreeMap<Name, MixinDecl>>,
     functions: Mutex<BTreeMap<Name, Function>>,
-    selectors: Option<Selectors>,
+    selectors: Option<SelectorCtx>,
     forward: Mutex<Option<ScopeRef>>,
     format: Format,
     /// The thing to use for `@content` in a mixin.
@@ -264,7 +263,7 @@ impl Scope {
         }
     }
     /// Create a new subscope of a given parent with selectors.
-    pub fn sub_selectors(parent: ScopeRef, selectors: Selectors) -> Self {
+    pub fn sub_selectors(parent: ScopeRef, selectors: SelectorCtx) -> Self {
         let format = parent.get_format();
         Scope {
             parent: Some(parent),
@@ -318,19 +317,18 @@ impl Scope {
         global: bool,
     ) -> Result<(), ScopeError> {
         if let Some((modulename, name)) = name.split_module() {
-            if let Some(module) = self.get_module(&modulename) {
-                if module
-                    .get_local_or_none(&Name::from_static("@scope_name@"))
-                    .is_some()
-                {
-                    return Err(ScopeError::ModifiedBuiltin);
-                } else {
-                    // Refuse to declare new var from outside module:
-                    let _check_existence = module.get(&name)?;
-                    return module.set_variable(name, val, default, global);
-                }
+            let module = self
+                .get_module(&modulename)
+                .ok_or(ScopeError::NoModule(modulename))?;
+            if module
+                .get_local_or_none(&Name::from_static("@scope_name@"))
+                .is_some()
+            {
+                return Err(ScopeError::ModifiedBuiltin);
             } else {
-                return Err(ScopeError::NoModule(modulename));
+                // Refuse to declare new var from outside module:
+                let _check_existence = module.get(&name)?;
+                return module.set_variable(name, val, default, global);
             }
         }
         /*if let Some(fwd) = self.opt_forward() {
@@ -506,9 +504,9 @@ impl Scope {
     }
 
     /// Get the selectors active for this scope.
-    pub fn get_selectors(&self) -> &Selectors {
+    pub fn get_selectors(&self) -> &SelectorCtx {
         lazy_static! {
-            static ref ROOT: Selectors = Selectors::root();
+            static ref ROOT: SelectorCtx = SelectorCtx::root();
         }
         self.selectors.as_ref().unwrap_or_else(|| {
             self.parent.as_ref().map_or(&ROOT, |p| p.get_selectors())
