@@ -18,7 +18,7 @@ fn test() {
         "Error: Top-level selectors may not contain the parent selector \"&\".\
          \n  ,\
          \n2 |   &post {\
-         \n  |   ^^^^^^\
+         \n  |   ^^^^^\
          \n  \'\
          \n  include.scss 2:3  @import\
          \n  input.scss 1:9    root stylesheet",
