@@ -11,9 +11,13 @@ fn test() {
     assert_eq!(
         runner().err("#{hdr(2,5)} { color: #08c; }"),
         "Error: expected selector.\
-         \n  ,\
+         \n  ,--> input.scss\
          \n1 | #{hdr(2,5)} { color: #08c; }\
-         \n  |   ^^^^^^^^\
+         \n  |   ^^^^^^^^ \
+         \n  \'\
+         \n  ,\
+         \n1 | hdr(2, 5) \
+         \n  |    = error in interpolated output\
          \n  \'\
          \n  input.scss 1:3  root stylesheet",
     );
