@@ -17,7 +17,7 @@ fn test() {
         "Error: Top-level selectors may not contain the parent selector \"&\".\
          \n  ,\
          \n1 | & foo {\
-         \n  | ^^^^^^\
+         \n  | ^\
          \n  \'\
          \n  input.scss 1:1  root stylesheet",
     );
