@@ -23,7 +23,7 @@ fn dollar() {
 fn double_operator() {
     assert_eq!(
         runner().err("a {b: calc(1px ** 2px)}\n"),
-        "Error: Expected number, variable, function, or calculation.\
+        "Error: Expected expression.\
          \n  ,\
          \n1 | a {b: calc(1px ** 2px)}\
          \n  |                 ^\
@@ -36,12 +36,12 @@ fn double_operator() {
 fn empty() {
     assert_eq!(
         runner().err("a {b: calc()}\n"),
-        "Error: Expected number, variable, function, or calculation.\
+        "Error: Missing argument.\
          \n  ,\
          \n1 | a {b: calc()}\
-         \n  |            ^\
+         \n  |       ^^^^^^\
          \n  \'\
-         \n  input.scss 1:12  root stylesheet",
+         \n  input.scss 1:7  root stylesheet",
     );
 }
 #[test]
@@ -49,31 +49,18 @@ fn empty() {
 fn hash() {
     assert_eq!(
         runner().err("a {b: calc(#)}\n"),
-        "Error: Expected number, variable, function, or calculation.\
+        "Error: Expected identifier.\
          \n  ,\
          \n1 | a {b: calc(#)}\
-         \n  |            ^\
+         \n  |             ^\
          \n  \'\
-         \n  input.scss 1:12  root stylesheet",
+         \n  input.scss 1:13  root stylesheet",
     );
 }
 mod interpolation {
     #[allow(unused)]
     use super::runner;
 
-    #[test]
-    #[ignore] // missing error
-    fn in_floating_function() {
-        assert_eq!(
-            runner().err("a {b: calc(1 c(#{d}))}\n"),
-            "Error: expected \"+\", \"-\", \"*\", \"/\", or \")\".\
-         \n  ,\
-         \n1 | a {b: calc(1 c(#{d}))}\
-         \n  |              ^\
-         \n  \'\
-         \n  input.scss 1:14  root stylesheet",
-        );
-    }
     #[test]
     #[ignore] // missing error
     fn in_function_arg() {
@@ -89,16 +76,20 @@ mod interpolation {
     }
     #[test]
     #[ignore] // missing error
-    fn in_parens() {
+    fn line_noise() {
         assert_eq!(
-            runner().err("a {b: calc(1 (#{c}))}\n"),
-            "Error: expected \"+\", \"-\", \"*\", \"/\", or \")\".\
+        runner().err(
+            "// Interpolation no longer shifts the parser into a special mode where it allows\
+             \n// any interpolated declaration value.\
+             \na {b: calc(!{@}#$%^&*#{c}_-[+]=)}\n"
+        ),
+        "Error: expected \")\".\
          \n  ,\
-         \n1 | a {b: calc(1 (#{c}))}\
-         \n  |              ^\
+         \n3 | a {b: calc(!{@}#$%^&*#{c}_-[+]=)}\
+         \n  |            ^\
          \n  \'\
-         \n  input.scss 1:14  root stylesheet",
-        );
+         \n  input.scss 3:12  root stylesheet",
+    );
     }
 }
 #[test]
@@ -106,12 +97,12 @@ mod interpolation {
 fn leading_operator() {
     assert_eq!(
         runner().err("a {b: calc(+ 1px)}\n"),
-        "Error: Expected digit.\
+        "Error: This expression can\'t be used in a calculation.\
          \n  ,\
          \n1 | a {b: calc(+ 1px)}\
-         \n  |             ^\
+         \n  |            ^^^^^\
          \n  \'\
-         \n  input.scss 1:13  root stylesheet",
+         \n  input.scss 1:12  root stylesheet",
     );
 }
 #[test]
@@ -119,12 +110,12 @@ fn leading_operator() {
 fn multiple_args() {
     assert_eq!(
         runner().err("a {b: calc(1px, 2px)}\n"),
-        "Error: expected \"+\", \"-\", \"*\", \"/\", or \")\".\
+        "Error: Only 1 argument allowed, but 2 were passed.\
          \n  ,\
          \n1 | a {b: calc(1px, 2px)}\
-         \n  |               ^\
+         \n  |       ^^^^^^^^^^^^^^\
          \n  \'\
-         \n  input.scss 1:15  root stylesheet",
+         \n  input.scss 1:7  root stylesheet",
     );
 }
 mod no_whitespace {
@@ -192,7 +183,20 @@ mod no_whitespace {
         runner().err(
             "a {b: calc(1 +1)}\n"
         ),
-        "Error: \"+\" and \"-\" must be surrounded by whitespace in calculations.\
+        "DEPRECATION WARNING on line 1, column 12 of input.scss: \
+         \nThis operation is parsed as:\n\
+         \n    1 + 1\n\
+         \nbut you may have intended it to mean:\n\
+         \n    1 (+1)\n\
+         \nAdd a space after + to clarify that it\'s meant to be a binary operation, or wrap\
+         \nit in parentheses to make it a unary operation. This will be an error in future\
+         \nversions of Sass.\n\
+         \nMore info and automated migrator: https://sass-lang.com/d/strict-unary\
+         \n  ,\
+         \n1 | a {b: calc(1 +1)}\
+         \n  |            ^^^^\
+         \n  \'\n\
+         \nError: \"+\" and \"-\" must be surrounded by whitespace in calculations.\
          \n  ,\
          \n1 | a {b: calc(1 +1)}\
          \n  |              ^\
@@ -237,7 +241,7 @@ mod no_whitespace {
 fn trailing_operator() {
     assert_eq!(
         runner().err("a {b: calc(1px *)}\n"),
-        "Error: Expected number, variable, function, or calculation.\
+        "Error: Expected expression.\
          \n  ,\
          \n1 | a {b: calc(1px *)}\
          \n  |                 ^\
@@ -250,7 +254,7 @@ fn trailing_operator() {
 fn unknown_operator() {
     assert_eq!(
         runner().err("a {b: calc(1px % 2px)}\n"),
-        "Error: expected \"+\", \"-\", \"*\", \"/\", or \")\".\
+        "Error: This operation can\'t be used in a calculation.\
          \n  ,\
          \n1 | a {b: calc(1px % 2px)}\
          \n  |                ^\
