@@ -5,6 +5,15 @@ fn runner() -> crate::TestRunner {
     super::runner().with_cwd("max")
 }
 
+#[test]
+fn case_insensitive() {
+    assert_eq!(
+        runner().ok("a {b: mAx(1px)}\n"),
+        "a {\
+         \n  b: 1px;\
+         \n}\n"
+    );
+}
 mod error {
     #[allow(unused)]
     use super::runner;
@@ -13,14 +22,16 @@ mod error {
     #[ignore] // wrong error
     fn complex_unit() {
         assert_eq!(
-            runner().err("a {b: max(1px*1px, 2%*2%)}\n"),
-            "Error: Number 1px*px isn\'t compatible with CSS calculations.\
+        runner().err(
+            "a {b: max(1px*1px, 2%*2%)}\n"
+        ),
+        "Error: Number calc(1px * 1px) isn\'t compatible with CSS calculations.\
          \n  ,\
          \n1 | a {b: max(1px*1px, 2%*2%)}\
          \n  |           ^^^^^^^\
          \n  \'\
          \n  input.scss 1:11  root stylesheet",
-        );
+    );
     }
     mod known_incompatible {
         #[allow(unused)]
@@ -101,10 +112,11 @@ mod error {
             );
         }
         #[test]
+        #[ignore] // wrong error
         fn no_args() {
             assert_eq!(
                 runner().err("a {b: max()}\n"),
-                "Error: At least one argument must be passed.\
+                "Error: Missing argument.\
          \n  ,\
          \n1 | a {b: max()}\
          \n  |       ^^^^^\
@@ -113,7 +125,7 @@ mod error {
             );
         }
     }
-    mod unitless_and_unit {
+    mod unitless_and_real {
         #[allow(unused)]
         use super::runner;
 
@@ -156,6 +168,32 @@ mod extra_whitespace {
         );
     }
 }
+mod math {
+    #[allow(unused)]
+    use super::runner;
+
+    #[test]
+    fn slash_as_division() {
+        assert_eq!(
+            runner().ok("b { \
+             \n  a: 2px / max(1.5);\
+             \n}\n"),
+            "b {\
+         \n  a: 1.3333333333px;\
+         \n}\n"
+        );
+    }
+}
+#[test]
+fn overridden() {
+    assert_eq!(
+        runner().ok("@function max($arg1, $arg2) {@return $arg1}\
+             \na {b: max(1, 2)}\n"),
+        "a {\
+         \n  b: 1;\
+         \n}\n"
+    );
+}
 mod preserved {
     #[allow(unused)]
     use super::runner;
@@ -196,7 +234,7 @@ mod preserved {
         #[allow(unused)]
         use super::runner;
 
-        mod unitless_and_unit {
+        mod unitless_and_real {
             #[allow(unused)]
             use super::runner;
 
@@ -308,7 +346,7 @@ mod simplified {
         use super::runner;
 
         #[test]
-        fn unitless_and_unit() {
+        fn unitless_and_real() {
             assert_eq!(
                 runner().ok("a {b: max(1px, 2.5 + 0.9px)}\n"),
                 "a {\
@@ -336,7 +374,7 @@ mod simplified {
         );
     }
     #[test]
-    fn unitless_and_unit() {
+    fn unitless_and_real() {
         assert_eq!(
             runner().ok("a {b: max(1px, 2.5, 0.9px)}\n"),
             "a {\
