@@ -24,8 +24,6 @@ fn main() -> Result<(), Error> {
         "spec",
         &[
             "core_functions/selector/extend", // not supported
-            "core_functions/selector/is_superselector", // not supported
-            "core_functions/selector/unify",  // not supported
             "directives/extend", // `@extend` is not supported at all
             "libsass-todo-issues/issue_221260.hrx", // stack overflow
             "libsass-todo-issues/issue_221262.hrx", // stack overflow
